==> tuia-ecb-center-api-1.1.0.29-happy-20200428.070531-15-sources.jar: cn/com/duiba/tuia/ecb/center/happy/remoteservice/RemoteHappyClearConfigService.java <==
package cn.com.duiba.tuia.ecb.center.happy.remoteservice;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.tuia.ecb.center.happy.dto.HappyClearMediaConfigDTO;
import cn.com.duiba.tuia.ecb.center.happy.dto.HappyClearPropConfigDTO;
import cn.com.duiba.tuia.ecb.center.happy.dto.HappyClearShoppingDTO;
import cn.com.duiba.tuia.ecb.center.happy.dto.HappyClearSignDTO;
import cn.com.duiba.tuia.ecb.center.happy.req.HappyClearPropConfigReq;
import cn.com.duiba.tuia.ecb.center.happy.req.HappyClearSignConfigReq;

import java.util.List;

@AdvancedFeignClient
public interface RemoteHappyClearConfigService {

    Boolean saveMediaConfig(HappyClearMediaConfigDTO happyClearMediaConfigDTO) throws BizException;

    Boolean deleteMediaConfig(Long appId) throws BizException;

    HappyClearShoppingDTO getExchangeConfig(Long appId) throws BizException;

    HappyClearMediaConfigDTO getMedisConfig(Long appId) throws BizException;

    Boolean saveSignConfig(HappyClearSignDTO happyClearSignDTO) throws BizException;

    Boolean saveBatchSignConfig(HappyClearSignConfigReq happyClearSignDTOS) throws BizException;

    Boolean deleteSignConfigByAppId(Long appId) throws BizException;

    Boolean deleteSignConfigById(Long id) throws BizException;

    Boolean savePropConfig(HappyClearPropConfigDTO clearPropConfigDTO) throws BizException;

    Boolean saveBatchPropConfig(HappyClearPropConfigReq clearPropConfigReq) throws BizException;

    Boolean deletePropConfigByAppId(Long appId) throws BizException;

    Boolean deletePropConfigById(Long id) throws BizException;
}

==> tuia-ecb-center-api-1.1.1.59-happy3-20210817.070945-1-sources.jar: cn/com/duiba/tuia/ecb/center/happy/remoteservice/RemoteHappyClearConfigService.java <==
package cn.com.duiba.tuia.ecb.center.happy.remoteservice;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.tuia.ecb.center.happy.dto.HappyClearMediaConfigDTO;
import cn.com.duiba.tuia.ecb.center.happy.dto.HappyClearPropConfigDTO;
import cn.com.duiba.tuia.ecb.center.happy.dto.HappyClearShoppingDTO;
import cn.com.duiba.tuia.ecb.center.happy.dto.HappyClearSignDTO;
import cn.com.duiba.tuia.ecb.center.happy.req.HappyClearConfigReq;
import cn.com.duiba.tuia.ecb.center.happy.req.HappyClearPropConfigReq;
import cn.com.duiba.tuia.ecb.center.happy.req.HappyClearSignConfigReq;

@AdvancedFeignClient
public interface RemoteHappyClearConfigService {

    Boolean saveMediaConfig(HappyClearMediaConfigDTO happyClearMediaConfigDTO) throws BizException;

    Boolean deleteMediaConfig(Long appId) throws BizException;

    HappyClearShoppingDTO getExchangeConfig(Long appId) throws BizException;

    HappyClearMediaConfigDTO getMedisConfig(Long appId) throws BizException;

    Boolean saveSignConfig(HappyClearSignDTO happyClearSignDTO) throws BizException;

    Boolean saveBatchSignConfig(HappyClearSignConfigReq happyClearSignDTOS) throws BizException;

    Boolean deleteSignConfigByAppId(Long appId) throws BizException;

    Boolean deleteSignConfigById(Long id) throws BizException;

    Boolean savePropConfig(HappyClearPropConfigDTO clearPropConfigDTO) throws BizException;

    Boolean saveBatchPropConfig(HappyClearPropConfigReq clearPropConfigReq) throws BizException;

    Boolean deletePropConfigByAppId(Long appId) throws BizException;

    Boolean deletePropConfigById(Long id) throws BizException;

    Boolean saveConfig(HappyClearConfigReq req) throws BizException;

}
